==> seven-elements-1.0.2%2B1.20.1-sources.jar: io/github/xrickastley/sevenelements/renderer/entity/model/CrystallizeShardEntityModel.java <==
package io.github.xrickastley.sevenelements.renderer.entity.model;

import io.github.xrickastley.sevenelements.SevenElements;
import io.github.xrickastley.sevenelements.entity.CrystallizeShardEntity;
import net.minecraft.class_5601;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_630;
import net.minecraft.class_7179;
import net.minecraft.class_7184;
import net.minecraft.class_7186;
import net.minecraft.class_7187;
import net.minecraft.class_8184;

public class CrystallizeShardEntityModel extends class_8184<CrystallizeShardEntity> {
	public static final class_5601 MODEL_LAYER = new class_5601(SevenElements.identifier("crystallize_shard"), "crystal");

	private final class_630 root;

	private static final class_7184 IDLE_ANIMATION = class_7184.class_7185.method_41818(3.0F).method_41817()
		.method_41820("crystal", new class_7179(class_7179.class_7183.field_37887,
			new class_7186(0.0F, class_7187.method_41829(0.0F, 0.0F, 0.0F), class_7179.class_7181.field_37884),
			new class_7186(3.0F, class_7187.method_41829(0.0F, 360.0F, 0.0F), class_7179.class_7181.field_37884)
		))
		.method_41820("particle1", new class_7179(class_7179.class_7183.field_37887,
			new class_7186(0.0F, class_7187.method_41829(0.0F, 0.0F, 0.0F), class_7179.class_7181.field_37884),
			new class_7186(3.0F, class_7187.method_41829(0.0F, 720.0F, 0.0F), class_7179.class_7181.field_37884)
		))
		.method_41820("particle2", new class_7179(class_7179.class_7183.field_37887,
			new class_7186(0.0F, class_7187.method_41829(0.0F, 0.0F, 0.0F), class_7179.class_7181.field_37884),
			new class_7186(3.0F, class_7187.method_41829(0.0F, 720.0F, 0.0F), class_7179.class_7181.field_37884)
		))
		.method_41820("particle3", new class_7179(class_7179.class_7183.field_37887,
			new class_7186(0.0F, class_7187.method_41829(0.0F, 0.0F, 0.0F), class_7179.class_7181.field_37884),
			new class_7186(3.0F, class_7187.method_41829(0.0F, 720.0F, 0.0F), class_7179.class_7181.field_37884)
		))
		.method_41820("particle4", new class_7179(class_7179.class_7183.field_37887,
			new class_7186(0.0F, class_7187.method_41829(0.0F, 0.0F, 0.0F), class_7179.class_7181.field_37884),
			new class_7186(3.0F, class_7187.method_41829(0.0F, 720.0F, 0.0F), class_7179.class_7181.field_37884)
		))
		.method_41821();

	public CrystallizeShardEntityModel(class_630 root) {
		super(1f, 1f);

		this.root = root;
	}

	@Override
	public class_630 method_32008() {
		return this.root;
	}

	public static class_5607 getTexturedModelData() {
		final class_5609 modelData = new class_5609();
		final class_5610 modelPartData = modelData.method_32111();
		final class_5610 crystal = modelPartData.method_32117("crystal", class_5606.method_32108(), class_5603.method_32090(0.0F, 15.0F, -0.5F));

		final class_5610 shard = crystal.method_32117("shard", class_5606.method_32108(), class_5603.method_32090(0.0F, 0.0F, 0.0F));

		shard.method_32117("shard_r1", class_5606.method_32108().method_32101(0, 0).method_32098(-1.0F, -1.0F, -3.0F, 4.0F, 4.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(-1.5F, -1.0F, 1.25F, 0.4656F, 0.422F, -0.6879F));
		crystal.method_32117("particle1", class_5606.method_32108().method_32101(10, 14).method_32098(-1.2313F, -1.0783F, -7.0F, 3.0F, 1.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -0.5F, 0.5F, 0.0F, -1.0908F, 0.5672F));

		final class_5610 particle2 = crystal.method_32117("particle2", class_5606.method_32108(), class_5603.method_32091(0.0F, -0.5F, 0.5F, 0.0F, 0.0F, -0.5672F));

		particle2.method_32117("particle2_r1", class_5606.method_32108().method_32101(10, 14).method_32098(-0.5F, -0.5F, -7.0F, 3.0F, 1.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(-0.2686F, -0.5783F, 0.0F, 0.0F, 0.2618F, 0.0F));

		final class_5610 particle3 = crystal.method_32117("particle3", class_5606.method_32108(), class_5603.method_32091(0.0F, -0.5F, 0.5F, 0.0F, 0.0F, 0.5672F));

		particle3.method_32117("particle3_r1", class_5606.method_32108().method_32101(10, 15).method_32098(0.25F, -1.5F, 7.0F, 3.0F, 1.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(-0.4814F, 0.4217F, 0.0F, 0.0F, -0.2618F, 0.0F));

		final class_5610 particle4 = crystal.method_32117("particle4", class_5606.method_32108(), class_5603.method_32091(0.0F, -0.5F, 0.5F, 0.0F, 0.0F, -0.5672F));

		particle4.method_32117("particle4_r1", class_5606.method_32108().method_32101(10, 15).method_32098(-0.5F, -0.5F, 7.0F, 3.0F, 1.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(-0.2686F, -0.5783F, 0.0F, 0.0F, 0.3054F, 0.0F));

		return class_5607.method_32110(modelData, 16, 16);
	}

	@Override
	public void setAngles(CrystallizeShardEntity entity, float limbSwing, float limbSwingAmount, float ageInTicks, float netHeadYaw, float headPitch) {
		this.method_32008().method_32088().forEach(class_630::method_41923);

		this.method_43782(entity.idleAnimationState, IDLE_ANIMATION, ageInTicks, 1.5f);
	}
}

==> seven-elements-1.0.4%2B1.21-sources.jar: io/github/xrickastley/sevenelements/renderer/entity/model/CrystallizeShardEntityModel.java <==
package io.github.xrickastley.sevenelements.renderer.entity.model;

import io.github.xrickastley.sevenelements.SevenElements;
import io.github.xrickastley.sevenelements.entity.CrystallizeShardEntity;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_5601;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_630;
import net.minecraft.class_7179;
import net.minecraft.class_7184;
import net.minecraft.class_7186;
import net.minecraft.class_7187;
import net.minecraft.class_8184;

public class CrystallizeShardEntityModel extends class_8184<CrystallizeShardEntity> {
	public static final class_5601 MODEL_LAYER = new class_5601(SevenElements.identifier("crystallize_shard"), "crystal");

	private final class_630 root;
	private final class_630 crystal;

	private static final class_7184 IDLE_ANIMATION = class_7184.class_7185.method_41818(3.0F).method_41817()
		.method_41820("crystal", new class_7179(class_7179.class_7183.field_37887,
			new class_7186(0.0F, class_7187.method_41829(0.0F, 0.0F, 0.0F), class_7179.class_7181.field_37884),
			new class_7186(3.0F, class_7187.method_41829(0.0F, 360.0F, 0.0F), class_7179.class_7181.field_37884)
		))
		.method_41820("particle1", new class_7179(class_7179.class_7183.field_37887,
			new class_7186(0.0F, class_7187.method_41829(0.0F, 0.0F, 0.0F), class_7179.class_7181.field_37884),
			new class_7186(3.0F, class_7187.method_41829(0.0F, 720.0F, 0.0F), class_7179.class_7181.field_37884)
		))
		.method_41820("particle2", new class_7179(class_7179.class_7183.field_37887,
			new class_7186(0.0F, class_7187.method_41829(0.0F, 0.0F, 0.0F), class_7179.class_7181.field_37884),
			new class_7186(3.0F, class_7187.method_41829(0.0F, 720.0F, 0.0F), class_7179.class_7181.field_37884)
		))
		.method_41820("particle3", new class_7179(class_7179.class_7183.field_37887,
			new class_7186(0.0F, class_7187.method_41829(0.0F, 0.0F, 0.0F), class_7179.class_7181.field_37884),
			new class_7186(3.0F, class_7187.method_41829(0.0F, 720.0F, 0.0F), class_7179.class_7181.field_37884)
		))
		.method_41820("particle4", new class_7179(class_7179.class_7183.field_37887,
			new class_7186(0.0F, class_7187.method_41829(0.0F, 0.0F, 0.0F), class_7179.class_7181.field_37884),
			new class_7186(3.0F, class_7187.method_41829(0.0F, 720.0F, 0.0F), class_7179.class_7181.field_37884)
		))
		.method_41821();

	public CrystallizeShardEntityModel(class_630 root) {
		super(1f, 1f);

		this.root = root;
		this.crystal = root.method_32086("crystal");
	}

	@Override
	public class_630 method_32008() {
		return this.root;
	}

	public static class_5607 getTexturedModelData() {
		final class_5609 modelData = new class_5609();
		final class_5610 modelPartData = modelData.method_32111();
		final class_5610 crystal = modelPartData.method_32117("crystal", class_5606.method_32108(), class_5603.method_32090(0.0F, 15.0F, -0.5F));

		final class_5610 shard = crystal.method_32117("shard", class_5606.method_32108(), class_5603.method_32090(0.0F, 0.0F, 0.0F));

		shard.method_32117("shard_r1", class_5606.method_32108().method_32101(0, 0).method_32098(-1.0F, -1.0F, -3.0F, 4.0F, 4.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(-1.5F, -1.0F, 1.25F, 0.4656F, 0.422F, -0.6879F));
		crystal.method_32117("particle1", class_5606.method_32108().method_32101(10, 14).method_32098(-1.2313F, -1.0783F, -7.0F, 3.0F, 1.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -0.5F, 0.5F, 0.0F, -1.0908F, 0.5672F));

		final class_5610 particle2 = crystal.method_32117("particle2", class_5606.method_32108(), class_5603.method_32091(0.0F, -0.5F, 0.5F, 0.0F, 0.0F, -0.5672F));

		particle2.method_32117("particle2_r1", class_5606.method_32108().method_32101(10, 14).method_32098(-0.5F, -0.5F, -7.0F, 3.0F, 1.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(-0.2686F, -0.5783F, 0.0F, 0.0F, 0.2618F, 0.0F));

		final class_5610 particle3 = crystal.method_32117("particle3", class_5606.method_32108(), class_5603.method_32091(0.0F, -0.5F, 0.5F, 0.0F, 0.0F, 0.5672F));

		particle3.method_32117("particle3_r1", class_5606.method_32108().method_32101(10, 15).method_32098(0.25F, -1.5F, 7.0F, 3.0F, 1.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(-0.4814F, 0.4217F, 0.0F, 0.0F, -0.2618F, 0.0F));

		final class_5610 particle4 = crystal.method_32117("particle4", class_5606.method_32108(), class_5603.method_32091(0.0F, -0.5F, 0.5F, 0.0F, 0.0F, -0.5672F));

		particle4.method_32117("particle4_r1", class_5606.method_32108().method_32101(10, 15).method_32098(-0.5F, -0.5F, 7.0F, 3.0F, 1.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(-0.2686F, -0.5783F, 0.0F, 0.0F, 0.3054F, 0.0F));

		return class_5607.method_32110(modelData, 16, 16);
	}

	@Override
	public void setAngles(CrystallizeShardEntity entity, float limbSwing, float limbSwingAmount, float ageInTicks, float netHeadYaw, float headPitch) {
		this.method_32008().method_32088().forEach(class_630::method_41923);

		this.method_43782(entity.idleAnimationState, IDLE_ANIMATION, ageInTicks, 1.5f);
	}

	@Override
	public void method_2828(class_4587 matrices, class_4588 vertexConsumer, int light, int overlay, int color) {
		crystal.method_22699(matrices, vertexConsumer, light, overlay, color);
	}
}
